/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2024, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package schemacrawler.tools.lint;

import java.util.logging.Logger;
import us.fatehi.utility.property.PropertyName;

/**
 * Defines a linter, and allows the creation of a new one, since multiple instances of the same
 * linter can be created.
 */
public abstract class BaseLinterProvider implements LinterProvider {

  private static final long serialVersionUID = -7188840789229724389L;

  private static final Logger LOGGER = Logger.getLogger(BaseLinterProvider.class.getName());

  private final PropertyName linterName;

  public BaseLinterProvider(final String linterId) {
    linterName = new PropertyName(linterId, LintUtility.readDescription(linterId));
  }

  /**
   * @{inheritDoc}
   */
  @Override
  public PropertyName getPropertyName() {
    return linterName;
  }
}
